==> cueplot-0.0.2-src.tar.gz: cueplot-0.0.2-src/gui/opt/MAxisTicsOptionWidget.h <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef M_AXIS_TICS_OPTION_WIDGET_INCLUDED
#define M_AXIS_TICS_OPTION_WIDGET_INCLUDED

#include "AxisOptionWidget.h"

class MAxisTics;

class QLineEdit;
class QRadioButton;

class MAxisTicsOptionWidget : public AxisOptionWidget
{
	Q_OBJECT

	public:
		MAxisTicsOptionWidget(QWidget *parent = 0);
		~MAxisTicsOptionWidget();

		void construct();

	private:
		// don't implement these
		MAxisTicsOptionWidget(const MAxisTicsOptionWidget &);
		MAxisTicsOptionWidget &operator=(const MAxisTicsOptionWidget &);

		void init();
		void apply();
		void constructWidget(QWidget *widget);
		void setOption(int axis);
		void setWidget(int axis);
		MAxisTics *mAxisTics;
		QRadioButton *defaultRadioButton;
		QRadioButton *freqRadioButton;
		QLineEdit *freqLineEdit;
};
#endif // M_AXIS_TICS_OPTION_WIDGET_INCLUDED

==> cueplot-0.0.3-src.tar.gz: cueplot-0.0.3-src/gui/opt/MAxisTicsOptionWidget.h <==
/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef M_AXIS_TICS_OPTION_WIDGET_INCLUDED
#define M_AXIS_TICS_OPTION_WIDGET_INCLUDED

#include "AxisOptionWidget.h"

class MAxisTics;

class QLineEdit;
class QRadioButton;

class MAxisTicsOptionWidget : public AxisOptionWidget
{
	Q_OBJECT

	public:
		explicit MAxisTicsOptionWidget(QWidget *parent = 0);
		~MAxisTicsOptionWidget();

		void construct();

	private:
		// don't implement these
		MAxisTicsOptionWidget(const MAxisTicsOptionWidget &);
		MAxisTicsOptionWidget &operator=(const MAxisTicsOptionWidget &);

		void init();
		void apply();
		void constructWidget(QWidget *widget);
		void setOption(int axis);
		void setWidget(int axis);
		MAxisTics *mAxisTics;
		QRadioButton *defaultRadioButton;
		QRadioButton *freqRadioButton;
		QLineEdit *freqLineEdit;
};
#endif // M_AXIS_TICS_OPTION_WIDGET_INCLUDED
